@@ -155,6 +155,22 @@
                   -607411559L, 55417736L, 1993198746L, 929142911L,
                   70336915L, -991939639L, -1545046851L, 304940986L)
                   
+makeAvail <- function(i, Tmat, Qmat, predx, predy, vary, varx, driftMod, lonadj){
+  .T <- matrix(0, 2+driftMod,2+driftMod)
+  .T[1,1] <- 1
+  .T[1,2] <- Tmat[i,1]
+  .T[2,2] <- Tmat[i,2]
+  if(driftMod){
+    .T[1,3] <- Tmat[i,3]
+    .T[3,3] <- Tmat[i,4]
+  }
+  Sy <- Qmat[i,1]
+  Sx <- Qmat[i,1]/(lonadj[i]^2)
+  ax <- as.double(predx[i,])
+  ay <- as.double(predy[i,])
+  c(c(.T%*%ax)[1], c(.T%*%ay)[1], (.T%*%varx[,,i]%*%t(.T))[1,1] + Sx, (.T%*%vary[,,i]%*%t(.T))[1,1] + Sy)
+}
+
 rmvtt <- function(mu, Sigma, df=Inf, lower, upper){
 	p <- length(mu)
 	out <- rep(NA,p)
